/* pantheon-wayland.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANTHEON_WAYLAND_H__
#define __SRC_PANTHEON_WAYLAND_H__

#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define PANTHEON_WAYLAND_TYPE_EXTENDED_BEHAVIOR (pantheon_wayland_extended_behavior_get_type ())
#define PANTHEON_WAYLAND_EXTENDED_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PANTHEON_WAYLAND_TYPE_EXTENDED_BEHAVIOR, PantheonWaylandExtendedBehavior))
#define PANTHEON_WAYLAND_IS_EXTENDED_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PANTHEON_WAYLAND_TYPE_EXTENDED_BEHAVIOR))
#define PANTHEON_WAYLAND_EXTENDED_BEHAVIOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), PANTHEON_WAYLAND_TYPE_EXTENDED_BEHAVIOR, PantheonWaylandExtendedBehaviorIface))

typedef struct _PantheonWaylandExtendedBehavior PantheonWaylandExtendedBehavior;
typedef struct _PantheonWaylandExtendedBehaviorIface PantheonWaylandExtendedBehaviorIface;

struct _PantheonWaylandExtendedBehaviorIface {
	GTypeInterface parent_iface;
};

VALA_EXTERN GType pantheon_wayland_extended_behavior_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void pantheon_wayland_extended_behavior_connect_to_shell (PantheonWaylandExtendedBehavior* self);
VALA_EXTERN void pantheon_wayland_extended_behavior_set_keep_above (PantheonWaylandExtendedBehavior* self);
VALA_EXTERN void pantheon_wayland_extended_behavior_make_centered (PantheonWaylandExtendedBehavior* self);
VALA_EXTERN void pantheon_wayland_extended_behavior_focus (PantheonWaylandExtendedBehavior* self);
VALA_EXTERN void pantheon_wayland_extended_behavior_make_modal (PantheonWaylandExtendedBehavior* self,
                                                    gboolean dim);

G_END_DECLS

#endif
